@@ -51,6 +51,10 @@ def MaybeGetAutoscalingOverride(msgs, asymmetric_autoscaling_option):
       and 'min_processing_units' not in asymmetric_autoscaling_option
       and 'max_processing_units' not in asymmetric_autoscaling_option
       and 'high_priority_cpu_target' not in asymmetric_autoscaling_option
+      and 'total_cpu_target' not in asymmetric_autoscaling_option
+      and 'disable_high_priority_cpu_autoscaling'
+      not in asymmetric_autoscaling_option
+      and 'disable_total_cpu_autoscaling' not in asymmetric_autoscaling_option
   ):
     return None
 
@@ -73,6 +77,18 @@ def MaybeGetAutoscalingOverride(msgs, asymmetric_autoscaling_option):
     obj.autoscalingTargetHighPriorityCpuUtilizationPercent = (
         asymmetric_autoscaling_option['high_priority_cpu_target']
     )
+  if 'total_cpu_target' in asymmetric_autoscaling_option:
+    obj.autoscalingTargetTotalCpuUtilizationPercent = (
+        asymmetric_autoscaling_option['total_cpu_target']
+    )
+  if 'disable_high_priority_cpu_autoscaling' in asymmetric_autoscaling_option:
+    obj.disableHighPriorityCpuAutoscaling = (
+        asymmetric_autoscaling_option['disable_high_priority_cpu_autoscaling']
+    )
+  if 'disable_total_cpu_autoscaling' in asymmetric_autoscaling_option:
+    obj.disableTotalCpuAutoscaling = (
+        asymmetric_autoscaling_option['disable_total_cpu_autoscaling']
+    )
   return obj
 
 
@@ -130,6 +146,22 @@ def MergeAutoscalingConfigOverride(msgs, existing_overrides, new_overrides):
         new_overrides.autoscalingTargetHighPriorityCpuUtilizationPercent
     )
 
+  if new_overrides.autoscalingTargetTotalCpuUtilizationPercent is not None:
+    result.autoscalingTargetTotalCpuUtilizationPercent = (
+        new_overrides.autoscalingTargetTotalCpuUtilizationPercent
+    )
+
+  if new_overrides.disableHighPriorityCpuAutoscaling is not None:
+    result.disableHighPriorityCpuAutoscaling = (
+        new_overrides.disableHighPriorityCpuAutoscaling
+    )
+    if result.disableHighPriorityCpuAutoscaling:
+      result.autoscalingTargetHighPriorityCpuUtilizationPercent = None
+
+  if new_overrides.disableTotalCpuAutoscaling is not None:
+    result.disableTotalCpuAutoscaling = new_overrides.disableTotalCpuAutoscaling
+    if result.disableTotalCpuAutoscaling:
+      result.autoscalingTargetTotalCpuUtilizationPercent = None
   return result
 
 
@@ -181,8 +213,10 @@ def Create(
     autoscaling_min_processing_units=None,
     autoscaling_max_processing_units=None,
     autoscaling_high_priority_cpu_target=None,
+    autoscaling_total_cpu_target=None,
     autoscaling_storage_target=None,
     asymmetric_autoscaling_options=None,
+    disable_downscaling=None,
     instance_type=None,
     expire_behavior=None,
     default_storage_type=None,
@@ -206,9 +240,11 @@ def Create(
     autoscaling_max_processing_units: The maximum number of processing units to
       use.
     autoscaling_high_priority_cpu_target: The high priority CPU target to use.
+    autoscaling_total_cpu_target: The total CPU target to use.
     autoscaling_storage_target: The storage target to use.
     asymmetric_autoscaling_options: A list of ordered dict of key-value pairs
       representing the asymmetric autoscaling options.
+    disable_downscaling: Whether to disable downscaling for the instance.
     instance_type: The instance type to use.
     expire_behavior: The expire behavior to use.
     default_storage_type: The default storage type to use.
@@ -244,7 +280,9 @@ def Create(
       or autoscaling_min_processing_units
       or autoscaling_max_processing_units
       or autoscaling_high_priority_cpu_target
+      or autoscaling_total_cpu_target
       or autoscaling_storage_target
+      or disable_downscaling is not None
   ):
     instance_obj.autoscalingConfig = msgs.AutoscalingConfig(
         autoscalingLimits=msgs.AutoscalingLimits(
@@ -255,8 +293,10 @@ def Create(
         ),
         autoscalingTargets=msgs.AutoscalingTargets(
             highPriorityCpuUtilizationPercent=autoscaling_high_priority_cpu_target,
+            totalCpuUtilizationPercent=autoscaling_total_cpu_target,
             storageUtilizationPercent=autoscaling_storage_target,
         ),
+        disableDownscaling=disable_downscaling,
     )
   if instance_type is not None:
     instance_obj.instanceType = instance_type
@@ -385,8 +425,10 @@ def Patch(
     autoscaling_min_processing_units=None,
     autoscaling_max_processing_units=None,
     autoscaling_high_priority_cpu_target=None,
+    autoscaling_total_cpu_target=None,
     autoscaling_storage_target=None,
     asymmetric_autoscaling_options=None,
+    disable_downscaling=None,
     clear_asymmetric_autoscaling_options=None,
     instance_type=None,
     expire_behavior=None,
@@ -406,7 +448,8 @@ def Patch(
   if (
       (autoscaling_min_nodes and autoscaling_max_nodes)
       or (autoscaling_min_processing_units and autoscaling_max_processing_units)
-  ) and (autoscaling_high_priority_cpu_target and autoscaling_storage_target):
+  ) and ((autoscaling_high_priority_cpu_target or autoscaling_total_cpu_target)
+         and autoscaling_storage_target):
     fields.append(_FIELD_MASK_AUTOSCALING_CONFIG)
   else:
     if autoscaling_min_nodes:
@@ -421,10 +464,16 @@ def Patch(
       fields.append(
           'autoscalingConfig.autoscalingTargets.highPriorityCpuUtilizationPercent'
       )
+    if autoscaling_total_cpu_target:
+      fields.append(
+          'autoscalingConfig.autoscalingTargets.totalCpuUtilizationPercent'
+      )
     if autoscaling_storage_target:
       fields.append(
           'autoscalingConfig.autoscalingTargets.storageUtilizationPercent'
       )
+    if disable_downscaling is not None:
+      fields.append('autoscalingConfig.disableDownscaling')
   client = apis.GetClientInstance(_SPANNER_API_NAME, _SPANNER_API_VERSION)
   msgs = apis.GetMessagesModule(_SPANNER_API_NAME, _SPANNER_API_VERSION)
 
@@ -439,7 +488,9 @@ def Patch(
       or autoscaling_min_processing_units
       or autoscaling_max_processing_units
       or autoscaling_high_priority_cpu_target
+      or autoscaling_total_cpu_target
       or autoscaling_storage_target
+      or disable_downscaling is not None
   ):
     instance_obj.autoscalingConfig = msgs.AutoscalingConfig(
         autoscalingLimits=msgs.AutoscalingLimits(
@@ -450,8 +501,10 @@ def Patch(
         ),
         autoscalingTargets=msgs.AutoscalingTargets(
             highPriorityCpuUtilizationPercent=autoscaling_high_priority_cpu_target,
+            totalCpuUtilizationPercent=autoscaling_total_cpu_target,
             storageUtilizationPercent=autoscaling_storage_target,
         ),
+        disableDownscaling=disable_downscaling,
     )
 
   if asymmetric_autoscaling_options is not None:
