@@ -108,9 +108,6 @@ def ProcessInstanceTypeAndNodes(args):
   return num_nodes
 
 
-@base.ReleaseTracks(
-    base.ReleaseTrack.GA, base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA
-)
 class ArgAdder(object):
   """A class for adding Bigtable command-line arguments."""
 
@@ -329,12 +326,12 @@ class ArgAdder(object):
     )
     return self
 
-  def AddViewQuery(self):
+  def AddViewQuery(self, required: bool = False):
     """Add argument for view query to the parser."""
     self.parser.add_argument(
         '--query',
         help='The query of the view.',
-        required=True,
+        required=required,
     )
     return self
 
@@ -628,6 +625,26 @@ class ArgAdder(object):
         num_nodes_default=3, require_all_essential_autoscaling_args=True
     )
 
+  def AddTags(self, required=False):
+    """Add argument group for tags to parser."""
+    self.parser.add_argument(
+        '--tags',
+        metavar='KEY=VALUE',
+        help=textwrap.dedent("""\
+            List of tags KEY=VALUE pairs to bind.
+            Each item must be specified in either ID
+            `<tag_key_id>=<tag_value_id>`
+            or namespace format
+            `<tag-key-namespaced-name>=<tag-value-short-name>`.
+            Example: `123/environment=production,123/costCenter=marketing`
+        """),
+        required=required,
+        type=arg_parsers.ArgDict(),
+        action=arg_parsers.UpdateAction,
+        hidden=True,  # TODO(b/745685146): Unhide
+    )
+    return self
+
 
 def InstanceAttributeConfig():
   return concepts.ResourceParameterAttributeConfig(
@@ -848,6 +865,26 @@ def AddMaterializedViewResourceArg(parser, verb: str) -> None:
   ).AddToParser(parser)
 
 
+def AddViewOverMaterializedView(parser):
+  """Add argument for view to the parser."""
+  msgs = util.GetAdminMessages()
+  view_enum_type = (
+      msgs.BigtableadminProjectsInstancesMaterializedViewsGetRequest.ViewValueValuesEnum
+  )
+  mapper = arg_utils.ChoiceEnumMapper(
+      '--view',
+      view_enum_type,
+      custom_mappings={
+          'SCHEMA_VIEW': 'schema',
+          'REPLICATION_VIEW': 'replication',
+          'FULL': 'full',
+      },
+      help_str='Specifies what type of information to return about the view.',
+      default='schema',
+  )
+  mapper.choice_arg.AddToParser(parser)
+
+
 def AddBackupResourceArg(parser, verb):
   """Add backup positional resource argument to the parser."""
   concept_parsers.ConceptParser([
