@@ -117,7 +117,7 @@ def _CommonArgs(
     support_specific_then_x_affinity=False,
     support_ipv6_only=False,
     support_graceful_shutdown=False,
-    support_igmp_query=False,
+    support_igmp_query=True,
     support_watchdog_timer=False,
     support_disk_labels=False,
     support_source_snapshot_region=False,
@@ -316,7 +316,7 @@ class Create(base.CreateCommand):
   _support_local_ssd_recovery_timeout = True
   _support_internal_ipv6_reservation = True
   _support_local_ssd_size = True
-  _support_vlan_nic = False
+  _support_vlan_nic = True
   _support_performance_monitoring_unit = True
   _support_source_instant_snapshot = False
   _support_boot_instant_snapshot_uri = False
@@ -324,7 +324,7 @@ class Create(base.CreateCommand):
   _support_enable_confidential_compute = True
   _support_specific_then_x_affinity = False
   _support_graceful_shutdown = False
-  _support_igmp_query = False
+  _support_igmp_query = True
   _support_watchdog_timer = False
   _support_disk_labels = False
   _support_ipv6_only = True
